homeScreen constant

int const homeScreen

Constants for wallpaper locations.

These constants represent the different locations where the wallpaper can be set:

  • homeScreen: Sets the wallpaper on the home screen.
  • lockScreen: Sets the wallpaper on the lock screen.
  • bothScreens: Sets the wallpaper on both the home and lock screens.

Implementation

static const int homeScreen = 1;